@@ -16,4 +16,4 @@
 # Import APIs into API package:
 from identitylib.photo_client.api.api_versions_api import APIVersionsApi
 from identitylib.photo_client.api.approved_photos_api import ApprovedPhotosApi
-from identitylib.photo_client.api.photos__including_unapproved_api import PhotosIncludingUnapprovedApi
+from identitylib.photo_client.api.photos_including_unapproved_api import PhotosIncludingUnapprovedApi
